#
# spec file for package calc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 2_15_1_0
%define libname libcalc%{soname}
Name:           calc
Version:        2.15.1.0
Release:        1.4
Summary:        C-style arbitrary precision calculator
License:        LGPL-2.1-only
Group:          Productivity/Scientific/Math
URL:            http://www.isthe.com/chongo/tech/comp/calc/index.html
Source0:        http://www.isthe.com/chongo/src/calc/%{name}-%{version}.tar.bz2
Source1:        README.openSUSE
BuildRequires:  fdupes
BuildRequires:  man
BuildRequires:  ncurses-devel >= 5.5
BuildRequires:  readline-devel >= 5.1
Requires:       %{libname} = %{version}-%{release}
Requires:       less >= 358

%description
Calc is arbitrary precision C-like arithmetic system that is a
calculator, an algorithm prototype and mathematical research tool.
Calc comes with a rich set of builtin mathematical and programmatic
functions.

%package -n %{libname}
Summary:        Arbitrary precision math library
Group:          System/Libraries

%description -n %{libname}
Part of the calc release consists of an arbitrary precision math link
library.  This link library is used by the calc program to perform its
own calculations.  If you wish, you can ignore the calc program entirely
and call the arbitrary precision math routines from your own C programs.

%package devel
Summary:        Development files for libcalc
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description devel
Part of the calc release consists of an arbitrary precision math link
library.  This link library is used by the calc program to perform its
own calculations.  If you wish, you can ignore the calc program entirely
and call the arbitrary precision math routines from your own C programs.

This package contains the files needed for building programs that use
this library.

%prep
%setup -q

cp "%{SOURCE1}" .

sed -i '/${CC} ${LIBCUSTCALC_SHLIB} ${CUSTCALC_OBJ}/a\
\tln -s $@ libcustcalc.so
' custom/Makefile

%define _NC_FLAGS %(ncursesw6-config --cflags)
%define _NC_LIBS %(ncursesw6-config --libs)

%define makevars \\\
    BINDIR=%{_bindir} \\\
    LIBDIR=%{_libdir} \\\
    SCRIPTDIR=%{_datadir}/%{name}/cscript \\\
    CALC_SHAREDIR=%{_datadir}/%{name} \\\
    CALC_INCDIR=%{_includedir}/calc \\\
    MANDIR=%{_mandir}/man1 \\\
    HAVE_FPOS="-DHAVE_NO_FPOS" \\\
    USE_READLINE="-DUSE_READLINE" \\\
    READLINE_LIB="-lreadline -lhistory %{_NC_LIBS} -L./custom -lcustcalc" \\\
    LD_SHARE="%{_NC_LIBS}" \\\
    ARCH_CFLAGS= \\\
    EXTRA_CFLAGS="%{optflags} -g -fno-strict-aliasing %{_NC_FLAGS}"

%build
make -e %{makevars}

%check
make -e %{makevars} chk

%install
make T=%{buildroot} %{makevars} install
rmdir %{buildroot}%{_includedir}/calc/custom

# dummy-install some docs etc. to create the symlinks
install -d -m 755 %{buildroot}%{_docdir}/%{name}
install -m 644 \
    BUGS CHANGES HOWTO.INSTALL LIBRARY \
    README.FIRST README.md README.openSUSE \
    custom/CUSTOM_CAL custom/HOW_TO_ADD \
    %{buildroot}%{_docdir}/%{name}/

# create symlinks to the help-dir for the help command, e.g. "help bugs"
ln -sf %{_docdir}/%{name}/BUGS \
    %{buildroot}%{_datadir}/%{name}/help/bug
ln -sf %{_docdir}/%{name}/BUGS \
    %{buildroot}%{_datadir}/%{name}/help/bugs
ln -sf %{_docdir}/%{name}/CHANGES \
    %{buildroot}%{_datadir}/%{name}/help/changes
ln -sf %{_docdir}/%{name}/CHANGES \
    %{buildroot}%{_datadir}/%{name}/help/change
ln -sf %{_docdir}/%{name}/CUSTOM_CAL \
    %{buildroot}%{_datadir}/%{name}/help/custom_cal
ln -sf %{_docdir}/%{name}/HOW_TO_ADD \
    %{buildroot}%{_datadir}/%{name}/help/new_custom

# add symlink to intro to docdir
ln -sf %{_datadir}/%{name}/help/intro \
    %{buildroot}%{_docdir}/%{name}/what-is-calc.txt

%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license COPYING COPYING-LGPL
%doc BUGS CHANGES HOWTO.INSTALL LIBRARY
%doc README.FIRST README.md README.openSUSE
%doc custom/CUSTOM_CAL custom/HOW_TO_ADD
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%doc %{_docdir}/%{name}/what-is-calc.txt

%files -n %{libname}
%attr(755, root, root) %{_libdir}/libcalc.so.*
%attr(755, root, root) %{_libdir}/libcustcalc.so.*

%files devel
%license COPYING COPYING-LGPL
%doc sample_many.c sample_rand.c sample.README README.md README.openSUSE
%doc %attr(644, root, root) BUGS LIBRARY
%{_includedir}/%{name}
%{_libdir}/libcalc.so
%{_libdir}/libcustcalc.so

%changelog
* Mon Nov 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Workaorund %%attr(644…) setting this attribute also on the doc
  directory if this is the first statement to copy docs over. The
  intention was clearly to set the files non-executable. Simply
  letting RPM copy the correct doc files first, using default
  attributes, results in the doc-dir having proper access modes.
* Fri Jul 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.15.1.0:
  * Converted all ASCII tabs to ASCII spaces using a 8 character
    tab stop, for all files, except for all Makefiles (plus rpm.mk).
    The command `git diff -w` reports no changes.  There is no
    functionality change in calc: only ASCII tabs to ASCII spaces.
  * Fixed trailblank.  It was pruning . in its find search.
  * Added check for ASCII tabs is non-Makefiles.
  * This version will form the basis for the calc v2 to calc v3 fork.
* Wed May 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.7:
  Fix bug regarding log2(x) #148
* Tue Feb 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.6:
  * A long standing memory leak in zrandom.c has been fixed.
* Fri Feb  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.5:
  * make clobber now removes the legacy files: have_fpos.h, help/man,
    and help/usage.  The latter 2 are now managed as help aliases
    in help.c.
  * make install now removes the legacy files: ${HELPDIR}/man
    and ${HELPDIR}/usage.
  * Fixed a problem where, when calc was linked with and uses GNU
    readline then for any multi-line copy-and-paste, only the first
    line is executed.  Thanks to GitHub user @malfisya for reporting
    this problem, and thanks to GitHub user @gromit1811 for doing
    the research needed to overcome deficiencies in the GNU readline
    documentation, and for supplying the work-a-round to allow
    multi-line copy-and-paste to work as expected!
* Fri Dec 22 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.4:
  * Fixed bug that caused calc to fail to compile filepos2z() in file.c
  on little endian machines for the Debian apcalc package.
  * Removed unused macros from zmath.h:
    + SWAP_B32_IN_HASH(dest, src)
    + SWAP_B16_IN_HASH(dest, src)
    + SWAP_B8_IN_HASH(dest, src)
    + SWAP_B32_IN_FLAG(dest, src)
    + SWAP_B16_IN_FLAG(dest, src)
    + SWAP_B8_IN_FLAG(dest, src)
  * When SWAP_HALF_IN_B32(dest, src), SWAP_B32_IN_FULL(dest, src),
    SWAP_B16_IN_HALF(dest, src), SWAP_B32_IN_bool(dest, src),
    or SWAP_B32_IN_LEN(dest, src), SWAP_HALF_IN_FILEPOS(dest, src)
    is an assignment such as:
    (*(dest) = *(src))
    We now case the dest and src pointers to the proper type before
    referencing and performing the assignment.
  * Documented unexpected behavior when calc is running in
    "shell script mode" and the prompt builtin function is used
    without the -p flag.  Updated help/prompt, help/unexpected
    and the calc man page accordingly.
  * Unless calc is given the -p command line option, calc will reopen
    stdin as /dev/null instead of just closing stdin.  This prevents
    subsequent opens grabbing the 1st file descriptor.
  * Disable regress tests 4709, 4710, and 7763 because they print
    multi-byte sequences, which are just fine for calc, the awk
    used to evaluate the regression suite output in some legacy
    systems report a "multibyte conversion failure".
  * Added a number of missing Makefile variables to the "make env" rule.
  * The man command is used to format the calc.1 man page into calc.usage.
  * The "help calc" command now prints the formatted calc man page (calc.usage).
  * The "help man" command now prints the formatted calc man page (calc.usage).
  * The "help usage" command now prints the formatted calc man page (calc.usage).
  * The file, calc.cat1, is formed by gzipping the calc.usage
    formatted man page.  The calc.cat1 is installed as the calc
    cat section 1 man page.
  * Avoiding use of modern [[ and ]] in Makefile for those legacy systems
    whose shell do not support them.  Be sure to use ||'s between []'s
    to avoid problems with legacy shell such as the Bourne shell. *sigh*
  * Fixed the order of "help full" to match the order of topics listed
    buy the "help help" command.
  * Sorted the halias[] help topics table in help.c using sort -d -u.
* Sun Dec 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.2:
  * Added ${FSANITIZE} make variable to Makefile.config to hold
    common Address Sanitizer (ASAN) optins to modern Linux and macOS.
    The Address Sanitizer is NOT enabled not compiled in by default.
    Improved comments in Makefile.local for RHEL9.2 (Linux) and for
    macOS 14.0 that, when uncommented and calc is recompiled (i.e.,
    make clobber all) will enable the Address Sanitizer (ASAN) for calc.
  * Fixed memory leaks in the logn, aversin, acoversin, avercos,
    acovercos, ahaversin, ahavercos, ahacovercos, aexsec,
    aexcsc, and acrd.
  * Fixed a compile error in zmath.h that impacted legacy 32-bit Big
    Endian machines.
  * Fixed the check for <sys/mount.h> when forming have_sys_mount.h.
  * Added "STATIC bool blum_initialized = false" to zrandom.c to improve
    how the code detects if the Blum-Blum-Shub pseudo-random number
    generator is seeded or not, and how to free the state correctly.
* Thu Oct  5 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.1:
  * The tarball for calc version 2.15.0.0 was missing version.h.
    The version.h is now listed as part of the calc distribution.
    See gh/lcn2/calc#112
* Wed Oct  4 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.15.0.0:
  * Added the several new trigonometric functions
  * Added log2(x [,eps]) builtin function
  * The sign element in a ZVALUE is now of type SIGN, which is either
    SB32 when MAJOR_VER < 3, or a bool otherwise
  * Added new logn(x, n [,eps]) builtin to compute logarithms to base n.
- Add calc-2.15.0.0-versionh.patch to fix build
  See gh/lcn2/calc#112
* Fri Aug 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.3.5:
  * Under macOS, to reduce dependency chains, we remove functions
    and data that are unreachable by the entry point or exported
    symbols.  In particular, the macOS linker is used with both
    "-dead_strip" and "-dead_strip_dylibs".
  * The libcalc shared library is now linked with libcustcalc.
* Tue Aug 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.3.4:
  * Fix typo in the make debug Makefile rule.
  * Fix install of statically linked calc under macOS
  * Update comments in Makefile.local about using -fsanitize
  * Add Makefile.local comments for macOS reduce dependency chains
  * Fix calc when CUSTOM is undefined, remove PASSDOWN values
  * Fix use of -dead_strip_dylibs for macOS linker
* Thu Aug  3 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.3.0:
  * The Darwin specific ${DARWIN_ARCH}, thay by default was unset,
    is now the ${ARCH_CFLAGS} Makefile variable.  Comments about
    various "-arch name" have been moved to the ${ARCH_CFLAGS} area.
  * Improved the output of the calcinfo rule by adding echos
    of various uname values as well as some top Makefile variables.
  * Fixed the BUGS file with respect to using `make debug`.
  * Added a final ls of `debug.out` for `make debug`.
* Mon Jul 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.2.2:
  * Removed references to obsolete Email addresses.
  * macOS Darwin defaults LCC to "cc".
* Thu Jul 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.2.1:
  * Added cal/fnv_tool.cal, a calc resource file defining:
    find_fnv_prime(bits)
    deprecated_fnv0(bits,fnv_prime,string)
    fnv_offset_basis(bits,fnv_prime)
    fnv1a_style_hash(bits,fnv_prime,prev_hash,string)
  * Fixed sorted order of cal/README.
* Sat Jul 22 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 2.14.2.0:
  * Ported calc to the s390x IBM Mainframe
* Thu Jun  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.1.6:
  * Fixed version numbers in two cases in CHANGES that referred
    to the 2.14.2.x instead of 2.14.1.x.
  * Rename MINGW Makefile variable (a holdover from MINGW32_NT-5.0)
    to OSNAME.
  * Fixed FUNCPTR typedef in hist.c to fix deprecated compiler warnings.
  * Fixed when USE_READLINE, READLINE_LIB, READLINE_EXTRAS, and
    READLINE_INCLUDE are set to empty (disable use of the GNU-readline
    facility).
  * Fix cases of spaces before tabs in Makefile and Makefile.simple.
  * Fixed obsolete references to the atoz() in LIBRARY to use the
    correct internal function name of str2z().
  * Fixed obsolete references to the atoq() in LIBRARY to use the
    correct internal function name of str2q().
  * Document in help/unexpected that * operator has has a higher
    precedence than << in calc, which differs from C.
* Tue Mar 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.14.1.5:
  * Fixed FUNCPTR typedef in hist.c to fix deprecated compiler warnings.
  * Fixed when USE_READLINE, READLINE_LIB, READLINE_EXTRAS, and
    READLINE_INCLUDE are set to empty (disable use of the GNU-readline
    facility).
* Wed Feb 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.14.1.3:
  * Fixed missing <string.h include in have_fpos_pos.c.
  * Change calc version from 2.14.1.2 to 2.14.2.3 as part of a test to
    build calc RPMs on a reference RHEL8.7 platform (formerly a RHEL7.9
    platform).
* Thu Dec  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.1.2:
  * Restored use of the #define FPOS_POS_LEN symbol.  This refers to
    the length of the __pos element (if the __pos element exists),
    the fpos_t type (if that type exists).
  * Changed SWAP_HALF_IN_FILEPOS(dest, src) mato to use FILEPOS_LEN Little
    Endian when FILEPOS is a simple scalar type (i.e., HAVE_FILEPOS_SCALAR
    is defined).
  * Changed #define HAVE_FPOS to HAVE_FGETSETPOS.
  * Corrected comment in have_fpos_pos.h.  The HAVE_FPOS_POS symbol was
    NOT related to fgetpos & fsetpos but rather if we we have an __pos
    element in FILEPOS.
  * Changed #define HAVE_NO_FPOS to HAVE_NO_FGETSETPOS.
  * Improved comments in have_fpos_pos.h to show why and how
    HAVE_FPOS_POS, FPOS_POS_BITS, and FPOS_POS_LEN were defined or undefed.
  * Changed showfiles builtin to print sizes cast to (long int) with
    the "%%ld" printf format to avoid implementations that do not support
    the "%%lld" printf format specifier.
  * Renamed have_fpos.h to have_fgetsetpos.h.  Renamed CALC_HAVE_FPOS_H
    to CALC_HAVE_FGETSETPOS_H.  The make install and the olduninstall
    rules remove the any old have_fpos.h that was previously installed.
  * Added swap_HALFs(dest, src, len) function to byteswap.c.
  * Calc can now handle Big Engian file position sizes that are a
    multiple of BASEB bits in length.  Before handle Big Engian file
    positions could only be 32 and 64 bits in length.  This will allow,
    for example, a Big Engian file position size of 128 (assuming that
    128/BASEB is is an integer).
  * Temporary workaround for musl libc systems such as gentoo Linux that
    allows them to compile calc and successfully run the regression test.
* Thu Dec  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.1.1:
  * Added a few remarks on calc version numbers to version.c.
  * Fixed how several headers are built.  On a number of systems, the source
    file failed to compile incorrectly.  This caused problems for systems in
    which header.h.def was not correct.
* Tue Apr 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.1.0:
  * Fixed alignment of show item section of help command.
  * Bug fix: While 0^0 == 1, now for y > 0, 0^y == 0.
  * Adjusted cal/test8900.cal to reflect this bug fix.
  * Added tests to cal/regress.cal to help verify bug fix is fixed.
* Wed Jan 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.14:
  * Fixed typo in Makefile.local comment.
- Remove calc-rpmlintrc: lib doesnt call exit() anymore
* Wed Jan 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.13:
  * Minor tweak to seed() builtin. Updated help/srand and help/srandom.
  * Moved Makefile.ship into Makefile.
  * Removed custom/Makefile.head and custom/Makefile.tail.
  * The "README.*" files and "HOWTO.INSTALL" file have been updated.
  * By default, compiler warnings have been turned up.
  * The readline, history and ncurses libraries are now default.
  * We have renamed "stable" as "production".
  * We have renamed "unstable" as "tested".
  * Fixed bug impacting how have_ustat.h was formed.
* Wed Jan 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.12:
  * Drop support for SunOS, IRIX and MINGW32_NT-5.0 targets.
  * Drop support for CLOCK_SGI_CYCLE.  Drop testing for __MSDOS__.
  * Minor improvement of various help files.  Made format of help
    files more consistent.
  * Corrected a few comments in zrandom.c, including a case where
    the comment referred to 1007 when it should have used 2^32.
  * Improved seed() generation.  Improved some comments in seed.c.
    Added have_environ.c to build have_environ.h in order to
    determine if: extern char **environ;  /* user environment */
    is an valid external symbol.
  * Fixed documentation that referred to the old additive 55
    generator.  We have been using the subtractive 100 in place
    of the additive 55 generator for a while now.
  * Fixed depend rule for custom/Makefile.
  * Fixed how Makefile variable SHELL is set on macOS vs. Linux.
    Using /bin/sh on macOS due to how zsh treats globs by default.
  * Added charbit.h to define CALC_CHARBIT which is either CHAR_BIT
    from <limits.h> or 8 or a value set by the Makefile variable
    CALC_CHARBIT.  Added have_limits.h to determine if <limits.h>
    is a system include file.
  * Fixed incorrect ustat_dev member ref in seed() builtin that
    was part of the unreleased calc v2.12.0.11.
* Wed Jan 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.10:
  * Pluged a number of memory leaks.
  * Fixed a few cases where v_subtype was not properly initialuzed.
  * Improved the way that internal pre-defined constants are managed.
    Removed unused internal pre-defined constants.  Added code to
    prevent an internal pre-defined constant (that was never allocated)
    from being freed.
* Wed Jan 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.9:
  * Due to issues with clang and Apple Silicon, ARCH_CFLAGS is now,
    by default, empty: ARCH_CFLAGS=
  * If you want to use, say, -march=native, then either change
    the Makefile or make with: make all ARCH_CFLAGS='-march=native'
  * Added arch and hardware as GNU Makefile computed values.
    As with ${target}, ${arch} and ${hardware} is computed by uname:
    target: uname -a
    arch: uname -p
    hardware: uname -m
  * Fixed compiling calc on Apple Silicon with homebrew.  On Apple
    Silicon, HomeBrew installs on into a different location.  The
    Makefile checks if ${hardware} is arm64 and adjusts the location
    of libraries such as readline and history accordingly.
* Wed Jan 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.7:
  * The help and man builtin commands now return an error when a
    help file cannot be opened, such as when there is no help file.
  * Added palindrome.cal resource file.  For example, to find the
    largest (highly probable) prime palindrome under 280 decimal
    digits (text tweet limit): prevprimepal(1e280)
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.6:
  * Fixed typo in cal/statistics.cal
  * Fixed an old Windoz pun in README.WINDOWS
  * Fixed a really obscure bug in the internal initconstants()
    function of const.c that has been sitting for over 31 years!
  * Fixed issues identied by the default CodeUL GitHub security code scan:
    + Wrong type of arguments to printf in have_fpos_pos.c
    + Multiplication result converted to larger type in zfunc.c
* Wed Oct 13 2021 Adam Majer <adam.majer@suse.de>
- Drop explicit -march definition (bsc#1191604, bsc#1100677)
* Wed Oct 13 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.3:
  * Added builtin functions to convert between degrees and
    degrees, minutes and seconds under the config("mod")
    See help/d2dms and help/d2dm.
  * Added builtin functions to convert between gradians and
    gradians, minutes and seconds under the config("mod")
    See help/g2gms and help/g2gm.
  * Added builtin functions to convert between hours and
    hours, minutes and seconds under the config("mod")
    See help/h2hms and help/h2hm.
  * Renumbered regression tests 3408 thru 3437, to 9102 thru 9131.
  * Updated Added hms.cal resource file to use h2hms() builtin.
  * Updated Added dms.cal resource file to use d2dms() builtin.
  * Fix minor typo in help/mod SYNOPSIS.
  * Fix minor typo in help/quo SYNOPSIS.
  * Added a few more examples to help/strcmp.
  * Added builtin functions to convert between degrees, minutes and
    seconds and degrees under the config("mod")
    See help/dms2d and help/dm2d.
  * Added builtin functions to convert between gradians, minutes and
    seconds and gradians under the config("mod")
    See help/g2gms and help/g2gm.
  * Added builtin functions to convert between hours, minutes and
    seconds and hours under the config("mod"):
    See help/hms2h and help/hm2h.
* Thu Sep  9 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.2:
  * The clean and clobber makefile rules no longer list custom/Makefile
    as a dependency.
  * Unfortunately due to the complex dependency issues between
    Makefile, Makefile.ship and custom/Makefile, parallel GNU make
    is NOT recommended.
  * Fixed a few typos in CHANGES.
  * As a side note: We stayed v2.13.x was kept for only a short time.
    The move to 2.14.x was motivated by non-compatible changes due to
    the default order of CALCRC, plus some new builtin functions.
  * More changes are likely, so we might see another v2.14.0.x release
    before things are declared "recommended stable".
  * Not that we wan to discourage people from trying v2.14.0, you should
    try it.  We just want things to become stable and well field tested
    before we reach the "recommended stable" release state.
* Tue Sep  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.14.0.0:
  * The :-separated default CALCRC value has been reversed.
    The default CALCRC was:
    ${CALC_SHAREDIR}/startup:~/.calcrc:./.calcinit
    The default CALCRC is now:
    ./.calcinit:~/.calcrc:${CALC_SHAREDIR}/startup
    See "help environment" for details.
  * Added engineering mode as per a GitHub pull request:
    ; config("mode","eng"),
    ; 10^41
    100e39
    or for example:
    ; base(1000),
    ; 2^23209-1
  ~402.87411577898877818187e6984
    For more information see: help base
  * Added regression test code for engineering mode.  Improved and
    expanded regression test code related to the base() and base2()
    builtin functions.
  * Fixed a critical bug in the above mentioned pull request where
    a call to base2(1000) would make calc unstable and likely to
    dump core.
* Fri May 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.13.0.1:
  * Replaced /usr/local with the use of ${PREFIX} in calc Makefiles.
    The ${PREFIX} is not the same as ${T}.  The ${T} specifies
    a top level directory under which calc installs things.
    While usually ${T} is empty, it can be specific path
    as if calc where "chrooted" during an install.
    The ${PREFIX} value, during install, is a path between
    the top level ${T} install directory and the object
    such as an include file.
  * Corrected a few more typos in Makefile comments.
  - Added Makefile.local, a file with a single comment.  The main
    Makefile includes Makefile.local just before the first all rule.
    One may override any Makefile setting by modifying Makefile.local.
    For example, Makefile.local could force BLD_TYPE:
    HAVE_STRING_H:= YES
    HAVE_TIMES_H:= YES
    SED:= /usr/local/bin/nsed
  - Added ${LOC_MKF} to specify the make of the file that is
    included just before the all file.  So one could place
    the above override lines into a different file and call
    make changing the ${LOC_MKF} value.  For example:
  - make LOC_MKF=Makefile.private clobber all chk
  - Updated HOWTO.INSTALL to mention Makefile.local.
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.13.0.0:
  * Fixed typo (missing quotes) in the env rule.
  * Fixed intendation problem in CHANGES.
  * Combined 2.12.9.1 changes into the 2.12.8.2 to 2.12.9.0
    range, and thus renamed the range to 2.12.8.2 to 2.12.9.1.
  * Fixed issues related to building Makefile.simple.
  * Fixed how the Makefile variable MANPATH is set for macOS.
  * Added a bunch of information to the near bottom of HOWTO.INSTALL
    on calc Makefiles.  This information discusses the various
    Makefiles found in the calc source.
  * Added comments in various calc Makefiles about their origin.
    In particular, for Makefiles that are constructed such as
    Makefile.simple, custom/Makefile and custom/Makefile.simple
    there are comments about how they were made.
  * For all calc Makefiles, including those in sub-directories,
    near the top there is now a line of the form:
    [#] SRC: ... some message about the origin ...
  * Fixed how the calc(1) man page is installed under macOS.
  * Fixed how calc man page in ${CATDIR} is formed.
  * Fixed how Makefile.simple is formed.
  * Fixed the #! calc script argument processing.  The initial #!
    line must end in a -f.  For example, if calc is in /usr/local/bin/calc,
    then the following would be the first line of a calc script:
  * It is common that -q be usde with a calc script, so assuming the
    same /usr/local/bin/calc path
  * Use of -s in the #! first line of a calc script is not needed
    since -f implies -f.
  * The argv() will now return values more typical of C's main().
    Before it returned one less than the number of arguments.  Now,
    for example, when calc is given 2 args, argv() will return 3.
  * The value of argv(0) will be the path to calc, or in the
    case of a #! calc cscript, it will return the name of the script.
  * Updated the calc man page and help/argv to reflect the
    above changes.
  * Improved the formatting of the calc man page.
  * Fixed the formation of the win32 sub-directory via the win32_hsrc
    Makefile rule.
  * Due to incompatible changes to the argv() function, and #! calc
    scripts, we are setting the version to the next minor number:
- Remove checksum.sha-256
* Fri Mar 12 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.12.19.0:
  * Added notes to help/unexpected about:
    display() will limit the number of digits printed after decimal point
    %%d will format after the decimal point for non-integer numeric values
    %%x will format as fractions for non-integer numeric values
    fprintf(fd, "%%d\n", huge_value) may need fflush(fd) to finish
  * Fixed Makefile dependencies for the args.h rule.
  * Fixed Makefile cases where echo with -n is used.  On some systems,
    /bin/sh does not use -n, so we must call /bin/echo -n instead
    via the ${ECHON} Makefile variable.
  * Add missing standard tools to sub-Makefiles to make them
    easier to invoke directly.
  * Sort lists of standard tool Makefile variables and remove duplicates.
  * Declare the SHELL at the top of Makefiles.
  * Fixed the depend rule in the custom Makefile.
  * Improved the messages produced by the depend in the Makefiles.
  * Changed the UNUSED define in have_unused.h to be a macro with
    a parameter.  Changed all use of UNUSED in *.c to be UNUSED(x).
  * Removed need for HAVE_UNUSED in building the have_unused.h file.
  * CCBAN is given to ${CC} in order to control if banned.h is in effect.
  * The banned.h attempts to ban the use of certain dangerous functions
    that, if improperly used, could compromise the computational integrity
    if calculations.
  * In the case of calc, we are motivated in part by the desire for calc
    to correctly calculate: even during extremely long calculations.
  * If UNBAN is NOT defined, then calling certain functions
    will result in a call to a non-existent function (link error).
* Mon Feb 22 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.12.8.2:
  * Calc can now correctly compile without CUSTOM being defined
* Tue Feb 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.12.8.1:
  * Fixed how the *.tar.bz2 are formed.  The calc-2.12.8.0.tar.bz2 file
    that was formed for calc version 2.12.8.0 was missing most files.
  * Expanded 'make chk' to also verify that 'make distchk' and 'make
    distlist' execute successfully.  This will help check a regression
    of the bug that produced the bogus calc-2.12.8.0.tar.bz2 file.
  * Added additional regression tests related 0^(zero_expression)==1.
* Tue Feb 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.12.8.0:
  * Fixed a mistake in "help intro" where some inserted text changed
    the value of "." and thus made the next result incorrect.
  * Clarified in "help factor" that 1 is returned if no
    factor below the limit was found.
  * Removed Makefile variable ${MAKEFILE_REV}.
  * The missing cscript/square.calc file has been restored.
  * Fixed compiler errors and warnings related to GCC.  In particular,
    gcc/9.3.1 and gcc/10.2.1 now compile calc without any compiler
    errors or warnings, even with -Werror -Wextra -pedantic.
  * To print out information about the calc compilation
    environment, we added the following make rule:
  * make calcinfo
  * Improved how 'make debug' operates.
  * Created a new calc bug report Email address.  Created a new
    calc question Email address.  Created a new calc contribution
    Email address.  See the BUGS file for details.
  * Added "help questions" to print the QUESTIONS help file.
  * If the environment variable $CALCHELP is defined and is non-empty,
    then calc help files will be in the directory by the $CALCHISTFILE
    environment variable.
  * If the environment variable $CALCCUSTOMHELP is defined and is
    non-empty, then custom calc help files will be in the directory
    by the $CALCCUSTOMHELP environment variable.
  * Fixed a number of typos in text and in source code comments.
* Sun Feb 14 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Build with march=corei7 instead of native
  to avoid compile-time CPU-detection (boo#1100677)
* Thu Feb  4 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.12.7.6:
  * The missing cscript/square.calc file has been restored.
* Thu Feb  4 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.12.7.5:
  * Requiring calc shell scripts to use -s -f at the end of the
    initial #! line.
  * Fixed /tmp/mersenne example in calc(1) man page.
  * Added make variable ${ARCH_CFLAGS}.  The ${ARCH_CFLAGS} is
    added after ${CCMISC} and before ${EXTRA_CFLAGS} when building
    the ${CFLAGS} for compiling C code.  are ${CC} when compiling
    C files.  The default value is:
  * By default, the calc history file is located in ~/.calc_history.
    Now, if the environment variable $CALCHISTFILE is defined
    and is non-empty, then calc history file will be defined
    by the $CALCHISTFILE environment variable.
  * Calc as defined 0^0 as 1.  However in the past, 0 raised to
    an expression that evaluated to zero returned 1.  The result
    was that 0^0 was different than 0^(6-6) or even 0^(0).
    Now, calc will return 1 for 0^(0) and 0^zero when zero == 0.
* Thu Nov 29 2018 mvetter@suse.com
- new stable release 2.12.7.2:
  + Fixed a segfault when getpwuid() returned NULL during initialization
  + Corrected Changes notes
* Mon Nov  5 2018 dnh@opensuse.org
- new stable release 2.12.7.0
  + The qprintnum() function now takes outdigits as a [optional] 3rd
    argument.
  + enhanced printf
  + various documentation updates
  + various fixes of build
* Sat Oct 20 2018 dnh@opensuse.org
- update to 2.12.6.10
  + minor improvements
* Tue Oct 16 2018 dnh@opensuse.org
- update to 2.12.6.9
  + various fixes and improvements, e.g. a number of core dump bugs
* Tue Oct  2 2018 dnh@opensuse.org
- update to 2.12.6.8
  + various fixes and improvements
* Thu Mar 29 2018 dnh@opensuse.org
- update to 2.12.6.7
  + various fixes and improvements (e.g. inputbuffer length)
* Tue Jan 30 2018 dnh@opensuse.org
- update to 2.12.6.5
- drop upstreamed calc-qmath-sequence-point.patch
* Thu Jan 18 2018 dnh@opensuse.org
- update to 2.12.6.4
  + Fixed a man page warning about ./myfile
  + Improved gen_v1(h,n) in lucas.cal for cases where h is not a multiple of 3.
  + Optimized the search for v(1) when h is a multiple of 3.
* Thu Sep  7 2017 dnh@opensuse.org
- update to 2.12.6.3
  + Improved gen_v1(h,n) in lucas.cal to use an even faster search method
  + Improved checking in lucas.cal
  + Fixed an C code indenting issue in zfunc.c
* Tue Aug  1 2017 Greg.Freemyer@gmail.com
- trivial doc fix
* Sun Jul 23 2017 dnh@opensuse.org
- update to 2.12.6.1
* Mon Jun  6 2016 dnh@opensuse.org
- update to 2.12.5.6
* Tue May 17 2016 dnh@opensuse.org
- update to 2.12.5.4
  +    Recompile to match current RHEL7.2 libc and friends
  +    Upstream made this release in order to update binary files not used in openSUSE
  +    No actual code change, other than the version number was bumped
* Mon Feb 15 2016 eshmarnev@suse.com
- add calc-rpmlintrc package to spec file
* Sat Feb 13 2016 dnh@opensuse.org
- update to 2.12.5.3
- add calc-qmath-sequence-point.patch
- replace calc-2.12.3.3-no-rpath.patch by using LD_SHARE=""
- add test for checksum
- bit of reworking the spec/merging with my old one (which is based
  on the include upstream calc.spec.in)
* Sun Aug  2 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 2.12.5.0
  + See Changes file for full list of changes
* Tue Oct  1 2013 Greg.Freemyer@gmail.com
- update to calc-2.12.4.13
  * major code cleanup and a few new functions
  * See Changes file for full list of changes
- added %%doc section to %%files
- added README.openSUSE
- changed the libname from libcalc2_12_4_3 to libcalc%%soname
- changed -n libcalc-devel to devel
- added Requires: %%{libname} = %%{version} to devel section
* Fri May 24 2013 Greg.Freemyer@gmail.com
- update to calc-2.12.4.8
  * fixes a bug uncovered in calc which caused script failures when calc
    was called within a while loop in BASH if the while loop was fed from
    stdin, due to calc's redirection/inheritance of stdin and no option to
    change this behavior.
* Thu Dec 27 2012 dvaleev@suse.com
- build with -DHAVE_NO_FPOS. Don't use fgetpos() and fsetpos() but
  use fseek() and ftell() instead. The code that generates
  fposval.h is completely broken. It tries to detect the size of
  fpos_t but fails on ppc.
* Tue Sep  4 2012 Greg.Freemyer@gmail.com
- ran thru spec-cleaner
* Wed Aug 29 2012 Greg.Freemyer@gmail.com
- update to calc-2.12.4.3
  - minor bug fixes
* Tue Sep 30 2008 mmarek@suse.cz
- kill rpath in installed binaries
- compile with $RPM_OPT_FLAGS
- hardlink duplicate files in /usr/share/calc/
- don't package /usr/include
* Tue Sep  2 2008 mmarek@suse.cz
- added missing ldconfig calls
* Thu Aug 21 2008 mmarek@suse.cz
- packaged  calc-2.12.3.3
